{% extends "django_lair/base.html" %}

{% block content %}
    <div class="bs-callout bs-callout-warning">
        <h4>Datum detail for: {{ datum.name }}</h4>
    </div>
    {% include "django_lair/datum_list_table.html" with table_id="table1" %}
    {% include "django_lair/chart.html" with label="Metric Frequency" data=activity labels=labels %}
{% endblock %}
