# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2016-12-01 03:46
from __future__ import unicode_literals

import datetime
from django.db import migrations, models
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('django_lair', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2016, 12, 1, 3, 46, 35, 159850, tzinfo=utc)),
            preserve_default=False,
        ),
    ]
