{% extends "django_lair/base.html" %}

{% block content %}
    <div class="bs-callout bs-callout-warning">
        <h4>User detail for: {{ user.id }}</h4>
        <p>User was created on {{ user.created }}</p>
    </div>
    {% include "django_lair/datum_list_table.html" with table_id="table1" %}
    {% include "django_lair/chart.html" with label="User Activity" data=activity labels=labels %}
{% endblock %}
