<table id="{{ table_id }}" class="table table-hover">
    <thead>
        <tr>
            <th>id</th>
            <th>name</th>
            <th>value</th>
            <th>user</th>
            <th>created</th>
        </tr>
    </thead>
    <tbody>
        {% for datum in datums %}
            <tr>
                <td>{{ datum.id }}</td>
                <td><a href="{% url 'datum_detail' datum.id %}">{{ datum.name }}</a></td>
                <td>{{ datum.value }}</td>
                <td><a href="{% url 'user_detail' datum.user.id %}">{{ datum.user }}</a></td>
                <td>{{ datum.created }}</td>
            </tr>
        {% endfor %}
    </tbody>
</table>
<script>
$(document).ready(function() {
    $('#{{ table_id }}').DataTable();
} );
</script>
